--------------------------------------------------------------------
-- Interface Options Panel
--------------------------------------------------------------------


---------------------------
-- create panels
---------------------------
function Glance.Functions.createPanels()
	for i=1,#Glance.Panels do
		local title, desc  = unpack(Glance.Panels[i])
		local parent
		if i==1 then parent = UIParent else parent = _G["panel1"] end
		_G["panel"..i] = CreateFrame( "Frame", "Glance_panel"..i, parent )
		_G["panel"..i].name = title
		if i > 1 then _G["panel"..i].parent = parent.name end
		InterfaceOptions_AddCategory(_G["panel"..i])
		if title ~= nil and i~=1 then
			local t = Glance.Functions.createText(_G["panel"..i],0,0,title,"GameFontNormalLarge","")
		end
		if desc ~= nil then
			local d = Glance.Functions.createText(_G["panel"..i],0,-20,desc,"GameFontHighlightSmall","")
		end
		if i==1 then
			--_G["panel"..i]:SetScript('OnShow', function(self) InterfaceOptionsFrame_OpenToCategory(panel2) end)
		end
		if i==4 or i==6 then
			_G["panel"..i]:SetScript('OnShow', function(self) Glance.Variables.overflowFix = true end)
		end
		if i==2 then
			_G["panel"..i]:SetScript('OnShow', function(self) Glance.Frames.Slider:Show() end)
			_G["panel"..i]:SetScript('OnHide', function(self) Glance.Frames.Slider:Hide() end)
		end
	end
end

---------------------------
-- create text
---------------------------
function Glance.Functions.createText(anchor,x,y,text,font,color)
	local fs = anchor:CreateFontString(nil, "ARTWORK", font)
	fs:SetPoint("TOPLEFT", 16+x, -16+y)
	fs:SetHeight(60)
	fs:SetWidth(350)
	fs:SetNonSpaceWrap(true)
	fs:SetWordWrap(true)
	fs:SetJustifyH("LEFT")
	fs:SetJustifyV("TOP")
	fs:SetText(color..text)
	return fs
end

---------------------------
-- create checkbox
---------------------------
function Glance.Functions.createCheckBoxes()
	for i=1,#Glance.CheckBoxes do
		local parent,x,y,opt,text,desc = unpack(Glance.CheckBoxes[i])
		_G["chk"..i] = CreateFrame('CheckButton', "Glance_chk"..i, parent, 'InterfaceOptionsCheckButtonTemplate')
		_G["Glance_chk"..i.."Text"]:SetText(text)
		_G["chk"..i]:SetPoint("TOPLEFT", 16+x, -16+y)
		if desc ~= nil then
			local d = Glance.Functions.createText(_G["chk"..i],12,-5,desc,"GameFontHighlightSmall","|cffffff00")
		end
		_G["chk"..i]:SetScript('OnClick', function(...) Glance.Functions.switchOptionValues(_G["chk"..i],opt) end )
	end
end

---------------------------
-- create scrollbars
---------------------------
function Glance.Functions.createScrollBars()
	for i=1,#Glance.Scrollbars do
		local parent,x,y,h,w,n,func,func2 = unpack(Glance.Scrollbars[i])
		_G["backframe"..i] = CreateFrame( "Frame", "Glance_BF"..i, parent)
		_G["backframe"..i]:SetPoint("TOPLEFT", x, y)
		_G["backframe"..i]:SetHeight(h)
		_G["backframe"..i]:SetWidth(w)
		_G["backframe"..i]:SetBackdrop(Glance.Arrays.backDrop)
		_G["Glance_SB"..i] = CreateFrame( "ScrollFrame", "Glance_SB"..i, _G["backframe"..i], "FauxScrollFrameTemplate")
		_G["Glance_SB"..i]:SetHeight(h)
		_G["Glance_SB"..i]:SetWidth(w-5)
		_G["Glance_SB"..i]:SetPoint("TOPLEFT",5,-8)
		_G["Glance_SB"..i]:SetPoint("BOTTOMRIGHT",-30,8)
		Glance.Functions.createScrollLines(_G["Glance_SB"..i],"Glance_SBE"..i,n,16,16)
		_G["Glance_SB"..i]:SetScript("OnVerticalScroll",function(self,offset) FauxScrollFrame_OnVerticalScroll(self, offset, 16, func) end)
		_G["Glance_SB"..i]:SetScript("OnShow", func2)
	end
end

---------------------------
-- create scrollbar lines
---------------------------
function Glance.Functions.createScrollLines(parent,name,count,height,width)
	for i=1, count do
		_G[name..i] = CreateFrame('CheckButton', name..i, parent, 'InterfaceOptionsCheckButtonTemplate')
		if i==1 then
			_G[name..i]:SetPoint("TOPLEFT", parent, "TOPLEFT")
		else
			_G[name..i]:SetPoint("TOPLEFT", name..i-1, "BOTTOMLEFT")
		end
		_G[name..i]:SetHeight(height)
		_G[name..i]:SetWidth(width)
	end
end

---------------------------
-- create options
---------------------------
function Glance.Functions.createOptionsPanel()
	Glance.Panels[1] = {"Glance",nil}
	Glance.Panels[2] = {"General Settings","General configuration settings for Glance."}
	Glance.Panels[3] = {"Modules","Enable or disable the following modules in Glance."}
	Glance.Panels[4] = {"Mounts","Select which mounts you wish to be visible on the mounts menu."}
	Glance.Panels[5] = {"Macros","The following macros can be made to randomize your mounts.  The choice of mount is determined by your settings in the Mounts panel."}
	Glance.Panels[6] = {"Pets","Select which companion pets you wish to be visible on the pets menu."}
	Glance.Panels[7] = {"About",GetAddOnMetadata("Glance","Notes")}
	Glance.Functions.createPanels()

	Glance.CheckBoxes[1] = {panel2,0,-60,"autoRepair","Auto repair armor",nil}
	Glance.CheckBoxes[2] = {panel2,0,-90,"moveUI","Move player, target, and buff frames down to make room",nil}
	Glance.CheckBoxes[3] = {panel2,0,-120,"sendStats","Send stats to party",nil}
	Glance.CheckBoxes[4] = {panel2,0,-150,"timePlayed","Show time played on login",nil}
	Glance.CheckBoxes[5] = {panel3,0,-60,"showGold","Show Gold",nil}
	Glance.CheckBoxes[6] = {panel3,0,-90,"showEmblems","Show Emblems",nil}
	Glance.CheckBoxes[7] = {panel3,0,-120,"showFriends","Show Friends",nil}
	Glance.CheckBoxes[8] = {panel3,0,-150,"showGuild","Show Guild",nil}
	Glance.CheckBoxes[9] = {panel3,0,-180,"showArmor","Show Armor",nil}
	Glance.CheckBoxes[10] = {panel3,0,-210,"showXP","Show XP",nil}
	Glance.CheckBoxes[11] = {panel3,0,-240,"showRep","Show Reputation",nil}
	Glance.CheckBoxes[12] = {panel3,0,-270,"showProfessions","Show Professions",nil}

	Glance.CheckBoxes[13] = {panel3,180,-60,"showLag","Show Latency (lag)",nil}
	Glance.CheckBoxes[14] = {panel3,180,-90,"showFPS","Show Framerate (fps)",nil}
	Glance.CheckBoxes[15] = {panel3,180,-120,"showMem","Show Memory (mem)",nil}
	Glance.CheckBoxes[16] = {panel3,180,-150,"showMounts","Show Mounts",nil}
	Glance.CheckBoxes[17] = {panel3,180,-180,"showPets","Show Pets",nil}
	Glance.CheckBoxes[18] = {panel3,180,-210,"showWG","Show Wintergrasp Timer",nil}
	Glance.CheckBoxes[19] = {panel3,180,-240,"showTB","Show Tol Barad Timer",nil}
	Glance.CheckBoxes[20] = {panel3,180,-270,"showLocation","Show Location",nil}
	Glance.CheckBoxes[21] = {panel3,180,-300,"showClock","Show Clock",nil}
	Glance.Functions.createCheckBoxes()

	Glance.Scrollbars[1] = {panel4,18,-60,345,378,20,Glance.Functions.updateScrollbarMounts,Glance.Functions.showScrollbarMounts}
	Glance.Scrollbars[2] = {panel6,18,-60,345,378,20,Glance.Functions.updateScrollbarPets,Glance.Functions.showScrollbarPets}
	Glance.Functions.createScrollBars()
	
	mac_1H = Glance.Functions.createText(panel5,15,-60,"/glance random","GameFontNormalSmall","")
	mac_1  = Glance.Functions.createText(panel5,15,-70,"Summons a random mount best suited for the area you are in.","GameFontHighlightSmall","")
	
	mac_2H = Glance.Functions.createText(panel5,15,-90,"/glance randomair","GameFontNormalSmall","")
	mac_2  = Glance.Functions.createText(panel5,15,-100,"Summons a random flying mount.","GameFontHighlightSmall","")
	
	mac_3H = Glance.Functions.createText(panel5,15,-120,"/glance randomland","GameFontNormalSmall","")
	mac_3  = Glance.Functions.createText(panel5,15,-130,"Summons a random land mount.","GameFontHighlightSmall","")
	
	mac_4H = Glance.Functions.createText(panel5,15,-150,"/glance randomwater","GameFontNormalSmall","")
	mac_4  = Glance.Functions.createText(panel5,15,-160,"Summons a random water mount.","GameFontHighlightSmall","")

	ab_verH = Glance.Functions.createText(panel7,0,-60,"Version","GameFontNormalLarge","")
	ab_ver  = Glance.Functions.createText(panel7,1,-80,GetAddOnMetadata("Glance","Version"),"GameFontHighlightSmall","")
	
	ab_updH = Glance.Functions.createText(panel7,0,-110,"Updated","GameFontNormalLarge","")
	ab_upd  = Glance.Functions.createText(panel7,1,-130,GetAddOnMetadata("Glance","X-Updated"),"GameFontHighlightSmall","")

	ab_athH = Glance.Functions.createText(panel7,0,-160,"Author","GameFontNormalLarge","")
	ab_ath  = Glance.Functions.createText(panel7,1,-180,GetAddOnMetadata("Glance","Author"),"GameFontHighlightSmall","")

	ab_catH = Glance.Functions.createText(panel7,0,-210,"Category","GameFontNormalLarge","")
	ab_cat  = Glance.Functions.createText(panel7,1,-230,GetAddOnMetadata("Glance","X-Category"),"GameFontHighlightSmall","")

	ab_newH = Glance.Functions.createText(panel7,0,-260,"New In This Version","GameFontNormalLarge","")
	ab_new  = Glance.Functions.createText(panel7,1,-280,GetAddOnMetadata("Glance","X-New"),"GameFontHighlightSmall","")

	-- ab_oldH = Glance.Functions.createText(panel7,0,-310,"New In Last Version","GameFontNormalLarge","")
	-- ab_old  = Glance.Functions.createText(panel7,1,-330,GetAddOnMetadata("Glance","X-Old"),"GameFontHighlightSmall","")

	sli_1H = Glance.Functions.createText(panel2,0,-210,"Select the scale of the Glance bar.","GameFontNormal","")
	sli_1  = Glance.Functions.createText(panel2,0,-225,"Default scale for Glance is 1.","GameFontHighlightSmall","")
	
	Glance.Frames.Slider = CreateFrame("Slider", "Glance.Frames.Slider", panel2, "OptionsSliderTemplate")
	Glance.Frames.Slider:ClearAllPoints()
	Glance.Frames.Slider:SetPoint("TOPLEFT", panel2, "TOPLEFT", 25, -275)
	Glance.Frames.Slider:SetMinMaxValues(0.5, 1.5)
	Glance.Frames.Slider:SetValue(Glance_Options.frameScale)
	getglobal(Glance.Frames.Slider:GetName() .. "Low"):SetText("0.5")
	getglobal(Glance.Frames.Slider:GetName() .. "High"):SetText("1.5")
	getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText(Glance.Functions.roundDecimal(Glance.Frames.Slider:GetValue(),1))
	Glance.Frames.Slider:SetValueStep(0.1)
	Glance.Frames.Slider:SetScript("OnValueChanged", function() Glance.Functions.sliderValueChanged() end) 
	
end

function Glance.Functions.sliderValueChanged()
	local scale = Glance.Functions.roundDecimal(Glance.Frames.Slider:GetValue(),1)
	getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText(scale)
	Glance_Options.frameScale = scale
	Glance.Frames.mainFrame:SetScale(scale)
	Glance.Functions.moveUI()
	Glance.Functions.updateAll()
end

---------------------------
-- pet overflow fix
---------------------------
function Glance.Functions.showScrollbarMounts()
	if Glance.Variables.overflowFix then
		Glance.Functions.updateScrollbarMounts()
	else
		return
	end
end

---------------------------
-- mount scrollbar update
---------------------------
function Glance.Functions.updateScrollbarMounts()
	FauxScrollFrame_Update(Glance_SB1,#Glance.Arrays.mount,20,16);  -- (frame, numItems/lines, numToDisplay, pixelheight/line) -- this is the 195 count...
	local line, lineplusoffset, thismount
	for line=1,20 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(Glance_SB1);
		if lineplusoffset <= #Glance.Arrays.mount then
			thismount =  Glance_Options.mounts[lineplusoffset]
			_G[getglobal("Glance_SBE1"..line):GetName().."Text"]:SetText(thismount[1])
			_G["Glance_SBE1"..line]:SetChecked(thismount[3])
			_G["Glance_SBE1"..line]:SetScript('OnClick', function(...) Glance.Functions.setPreferredMount() end )
			_G["Glance_SBE1"..line]:Show();
		else
			_G["Glance_SBE1"..line]:Hide();
		end
	end
	Glance.Variables.overflowFix = false
	Glance_SB1:Show()
end

---------------------------
-- mount scrollbar click
---------------------------
function Glance.Functions.setPreferredMount()
	local line, pref, name
	for line=1,20 do
		name = _G[getglobal("Glance_SBE1"..line):GetName().."Text"]:GetText()
		pref = _G["Glance_SBE1"..line]:GetChecked()
		if pref == 1 then
			pref = true
		else
			pref = false
		end
		for i=1,#Glance.Arrays.mount do
			if Glance_Options.mounts[i][1] == name then
				Glance_Options.mounts[i][3] = pref
			end
		end
	end
end

---------------------------
-- pet overflow fix
---------------------------
function Glance.Functions.showScrollbarPets()
	if Glance.Variables.overflowFix then
		Glance.Functions.updateScrollbarPets()
	else
		return
	end
end

---------------------------
-- pet scrollbar update
---------------------------
function Glance.Functions.updateScrollbarPets()
	FauxScrollFrame_Update(Glance_SB2,#Glance.Arrays.pet,20,16);  -- (frame, numItems/lines, numToDisplay, pixelheight/line)
	local line, lineplusoffset, thispet
	for line=1,20 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(Glance_SB2);
		if lineplusoffset <= #Glance.Arrays.pet then
			thispet =  Glance_Options.pets[lineplusoffset]
			_G[getglobal("Glance_SBE2"..line):GetName().."Text"]:SetText(thispet[1])
			_G["Glance_SBE2"..line]:SetChecked(thispet[2])
			_G["Glance_SBE2"..line]:SetScript('OnClick', function(...) Glance.Functions.setPreferredPet() end )
			_G["Glance_SBE2"..line]:Show();
		else
			_G["Glance_SBE2"..line]:Hide();
		end
	end
	Glance.Variables.overflowFix = false
	Glance_SB2:Show()
end

---------------------------
-- pet scrollbar click
---------------------------
function Glance.Functions.setPreferredPet()
	local line, pref, name
	for line=1,20 do
		name = _G[getglobal("Glance_SBE2"..line):GetName().."Text"]:GetText()
		pref = _G["Glance_SBE2"..line]:GetChecked()
		if pref == 1 then
			pref = true
		else
			pref = false
		end
		for i=1,#Glance.Arrays.pet do
			if Glance_Options.pets[i][1] == name then
				Glance_Options.pets[i][2] = pref
			end
		end
	end
end

---------------------------
-- preload checkboxes
---------------------------
function Glance.Functions.setOptionValues()
	for i=1,#Glance.CheckBoxes do
		_G["chk"..i]:SetChecked(Glance_Options[Glance.CheckBoxes[i][4]])
	end
end

---------------------------
-- checkbox onclick
---------------------------
function Glance.Functions.switchOptionValues(btn,val)
	if btn:GetChecked() == nil then
		Glance_Options[val] = false
	else
		Glance_Options[val] = true
	end
	if btn:GetName() == "Glance_chk2" then
		Glance.Functions.moveUI()
	end
	Glance.Functions.updateAll()
end